include <../variables.scad>

module corner(){

    union(){
        difference(){
            cube([quadpipe_side, quadpipe_side , quadpipe_side]); // core cube so we have a rim that closes with the connecting pipe

            translate([corner_thickness * 2, corner_thickness * 2, corner_thickness * 2]){
                union(){ // cut out inner fill, we'll probably want to lay cabling through these things
                    cube([quadpipe_side, corner_inner, corner_inner]);
                    cube([corner_inner, corner_inner, quadpipe_side]);
                }
            }
        }

        translate([quadpipe_thickness, quadpipe_thickness, quadpipe_thickness]){
            difference(){

                union(){ // union of bigger cubes on the inside

                    cube([quadpipe_side * 2, quadpipe_inner , quadpipe_inner]);
                    cube([quadpipe_inner, quadpipe_inner, quadpipe_side * 2]);
                }

                translate([corner_thickness, corner_thickness, corner_thickness]){

                    union(){ // and the cutout inside
                        cube([quadpipe_side * 2, corner_inner , corner_inner]);
                        cube([corner_inner, corner_inner, quadpipe_side * 2]);
                    }
                }
            }
        }
    }
}

module corner_core(){

    // builds a cornerpiece that fits quadpipes as defined via variables

    union(){
        difference(){
            cube([quadpipe_side, quadpipe_side , quadpipe_side]); // core cube so we have a rim that closes with the connecting pipe

            translate([corner_thickness * 2, corner_thickness * 2, corner_thickness * 2]){
                union(){ // cut out inner fill, we'll probably want to lay cabling through these things
                    cube([quadpipe_side, corner_inner, corner_inner]);
                    cube([corner_inner, quadpipe_side, corner_inner]);
                    cube([corner_inner, corner_inner, quadpipe_side]);
                }
            }
        }

        translate([quadpipe_thickness, quadpipe_thickness, quadpipe_thickness]){
            difference(){

                union(){ // union of bigger cubes on the inside

                    cube([quadpipe_side * 2, quadpipe_inner , quadpipe_inner]);
                    cube([quadpipe_inner, quadpipe_side * 2, quadpipe_inner]);
                    cube([quadpipe_inner, quadpipe_inner, quadpipe_side * 2]);
                }

                translate([corner_thickness, corner_thickness, corner_thickness]){

                    union(){ // and the cutout inside
                        cube([quadpipe_side * 2, corner_inner , corner_inner]);
                        cube([corner_inner, quadpipe_side * 2, corner_inner]);
                        cube([corner_inner, corner_inner, quadpipe_side * 2]);
                    }
                }
            }
        }
    }
}

module corner_battery(){

    // builds a 't' cornerpiece, which has one more connector than the regular corner.
    // used for the battery compartment

    translate([0,0, quadpipe_side * -1]){
        difference(){
            union(){
                corner_core();

                translate([quadpipe_thickness, quadpipe_thickness, quadpipe_side * -1]){
                    cube([quadpipe_inner, quadpipe_inner, quadpipe_side]); // outer cube for the new connector
                }
            }

            translate([quadpipe_thickness + corner_thickness, quadpipe_thickness + corner_thickness, quadpipe_side * -1]){
                cube([corner_inner, corner_inner, quadpipe_side + quadpipe_thickness + corner_thickness]);
            }
        }
    }
}


// Place demo instances

corner();

translate([quadpipe_side * 3, 0, 0]){
    corner_core();
}

translate([quadpipe_side * 6, 0, 0]){
    corner_battery();
}
