include <../variables.scad>

module hinge_rail(){
    render(convexity=1){
        union(){
            translate([0, quadpipe_thickness, 0]){

                union(){

                    difference(){
                        cube([hinge_length, quadpipe_inner, hinge_rail_height]);

                        translate([0, hinge_rail_thickness, 0]){
                            cube([hinge_length, quadpipe_inner - 2 * hinge_rail_thickness, hinge_rail_height - hinge_rail_thickness]);
                        }
                    }

                    translate([0, quadpipe_inner / 2 - hinge_rail_depth / 2, hinge_rail_height]){
                        cube([hinge_length, hinge_rail_depth, quadpipe_thickness]);
                    }
                }
            }

            translate([0, 0, hinge_rail_height + quadpipe_thickness]){
                cube([hinge_length, quadpipe_side, hinge_rail_thickness]);
            }
        }
    }
}

module hinge_270(){
    
    render(convexity=1){

        translate([0, -quadpipe_side, -quadpipe_side]){

            difference(){
                difference(){
                    union(){
                        //cube([hinge_length, quadpipe_side, quadpipe_side]);
                        translate([hinge_length, 0, 0]){
                            rotate([0, -90, 0]){
                                linear_extrude(height=hinge_length){
                                    polygon(
                                        points=[
                                            [0,0],
                                            [0, quadpipe_side],
                                            [quadpipe_side, quadpipe_side],
                                            [quadpipe_side, quadpipe_side - (hinge_270_hole + hinge_thickness) / 2]
                                        ]
                                    );
                                }
                            }
                        }

                        translate([0, quadpipe_side, quadpipe_side]){
                            rotate([0, 90, 0]){
                                cylinder(r=(hinge_270_hole + hinge_thickness) / 2, h=hinge_length);
                            }

                        }

                        translate([0, 0, -hinge_rail_height - quadpipe_thickness - hinge_rail_thickness]){
                            hinge_rail();
                        }
                    }

                    for(i=[1:2:hinge_segments]){ 
                        /*translate([hinge_segment_length * i, quadpipe_side, quadpipe_side]){ // cylinder cutout

                            rotate([0, 90, 0]){
                                cylinder(r=quadpipe_side, h=hinge_segment_length);
                            }
                        }*/


                        translate([hinge_segment_length * i, 0, 0]){ // cube cutout
                            cube([hinge_segment_length, quadpipe_side * 2, quadpipe_side * 2]);
                        }
                    }
                }

                // hole in the middle for a hinge pin/pipe
                translate([0, quadpipe_side, quadpipe_side]){
                    rotate([0, 90, 0]){
                        cylinder(d=hinge_270_hole, h=hinge_length);
                    }
                }
            }
        }
    }
}


module hinge_270_start(){
    
    // hinge_270 with a length of quadpipe_side * 2 removed from the rail so we don't collide with corner pieces
    render(convexity=1){

        union(){
            difference(){

                hinge_270();

                translate([0, -quadpipe_side, -quadpipe_side - hinge_rail_height - quadpipe_thickness - hinge_rail_thickness]){
                    cube([quadpipe_side * 2, quadpipe_side, hinge_rail_height + quadpipe_thickness]);
                }
            }

            // tongue thing
            translate([quadpipe_side, -quadpipe_side / 2 - hinge_rail_depth / 2, -quadpipe_side - hinge_rail_thickness * 2]){
                cube([quadpipe_side, hinge_rail_depth, quadpipe_thickness]);
            }
        }
    }
}

module hinge_270_end(){
    render(convexity=1){
        union(){
            difference(){

                hinge_270();

                translate([hinge_length - quadpipe_side * 2, -quadpipe_side, -quadpipe_side - hinge_rail_height - quadpipe_thickness - hinge_rail_thickness]){
                    cube([quadpipe_side * 2, quadpipe_side, hinge_rail_height + quadpipe_thickness]);
                }
            }

            // tongue thing
            translate([hinge_length - quadpipe_side * 2, -quadpipe_side / 2 - hinge_rail_depth / 2, -quadpipe_side - hinge_rail_thickness * 2]){
                cube([quadpipe_side, hinge_rail_depth, quadpipe_thickness]);
            }
        }
    }
}

module hinge_270_array(){

    // an array of hinge_side over core_length with start and end hinges placed properly

    for(i=[0:1:length_hinge_count - 1]){

        translate([i * hinge_length, 0, 0]){
            if(i == 0){
                hinge_270_start();
            } else if(i == length_hinge_count - 1){
                hinge_270_end();
            } else {
                hinge_270();
            }
        }
    }
}
module hinge_side(){

    render(convexity=1){
        union(){
            //translate([0, 0, hinge_rail_height + quadpipe_thickness + hinge_rail_thickness]){
            translate([0, -quadpipe_side / 2, -quadpipe_side / 2]){
                difference(){

                    difference(){
                        union(){
                            rotate([0, 90, 0]){
                                //cylinder(d=quadpipe_side, h=hinge_length);
                                linear_extrude(height=hinge_length){
                                    polygon(
                                        points=[
                                            [0, 0],
                                            [-quadpipe_side / 2 - hinge_thickness, quadpipe_side / 2],
                                            [0, quadpipe_side]
                                        ]
                                    );
                                }

                                translate([-quadpipe_side / 2, quadpipe_side / 2, 0]){
                                    cylinder(d=hinge_side_hole + hinge_thickness, h=hinge_length);
                                }
                            }

                        }


                        for(i=[1:2:hinge_segments]){ // cut out segment for facing hinge part from other wall

                            union(){
                                translate([hinge_segment_length * i, quadpipe_side / 2, quadpipe_side / 2]){ // cylinder cutout
                                    rotate([0, 90, 0]){
                                        cylinder(d=quadpipe_side, h=hinge_segment_length);
                                    }
                                }

                                translate([hinge_segment_length * i, 0, 0]){
                                    cube([hinge_segment_length, quadpipe_side / 2, quadpipe_side]);
                                }
                            }
                        }
                    }

                    translate([0, quadpipe_side / 2, quadpipe_side / 2]){ // hole for the pin in the middle
                        rotate([0, 90, 0]){
                            cylinder(d=hinge_side_hole, h=hinge_length);
                        }
                    }
                }
            }

            translate([0, -quadpipe_side / 2, -quadpipe_side / 2 - hinge_rail_height - quadpipe_thickness - hinge_rail_thickness]){
                hinge_rail();
            }

        }
    }
}

module hinge_side_start(){

    // hinge_side with a length of quadpipe_side * 2 removed from the rail so we don't collide with corner pieces
    render(convexity=1){
        union(){
            difference(){

                hinge_side();

                cube([quadpipe_side * 2, quadpipe_side, hinge_rail_height + quadpipe_thickness]);
            }

            // a bit of extra "tongue" for inside the rail slit blocked by corners
            translate([quadpipe_side, quadpipe_side / 2 - hinge_rail_depth / 2, hinge_rail_height]){
                cube([quadpipe_side, hinge_rail_depth, quadpipe_thickness]);
            }
        }
    }
}

module hinge_side_end(){

    render(convexity=1){
        union(){
            difference(){

                hinge_side();

                translate([hinge_length - quadpipe_side * 2, 0, 0]){
                    cube([quadpipe_side * 2, quadpipe_side, hinge_rail_height + quadpipe_thickness]);
                }
            }

            // a bit of extra "tongue" for inside the rail slit blocked by corners
            translate([hinge_length - quadpipe_side * 2, quadpipe_side / 2 - hinge_rail_depth / 2, hinge_rail_height]){
                cube([quadpipe_side, hinge_rail_depth, quadpipe_thickness]);
            }
        }
    }
}

module hinge_side_array(){

    // an array of hinge_side over core_length with start and end hinges placed properly

    for(i=[0:1:length_hinge_count - 1]){

        translate([i * hinge_length, 0, 0]){
            if(i == 0){
                hinge_side_start();
            } else if(i == length_hinge_count - 1){
                hinge_side_end();
            } else {
                hinge_side();
            }
        }
    }
}



// hinge270 test assembly

hinge_270();

translate([hinge_length, 0, 0]){
    rotate([$t*-270, 0, 180]){
        hinge_270();
    }
}


// hinge_side test assembly

translate([hinge_length + quadpipe_side, 0, 0]){
    hinge_side();
    translate([hinge_length, 0, 0]){
        rotate([90 + ($t * 90), 0, 180]){
            hinge_side();
        }
    }
}

// place start and end hinges to test make sure they fit and make sense

translate([(hinge_length + quadpipe_side) * 2, 0, 0]){
    hinge_side_start();
    translate([hinge_length, 0, 0]) { hinge_side_end(); }
}
